# Copyright (C) 2010 The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

# This script is used to convert a dependency file generated by a cygwin-less
# GCC compiler program into something that can be parsed into a cygwin-based
# GNU Make program.
#
# More specifically, it's going to translate stuff like:
#
# D:/Stuff/source.o: \
#  D:/Stuff/source.h \
#  C:/NDK/sysroot/include/string.h \
#  C:/NDK/sysroot/include/malloc.h
#
# into
#
# /cygdrive/d/Stuff/source.o: \
#  /cygdrive/d/Stuff/source.h \
#  /cygdrive/c/NDK/sysroot/include/string.h \
#  /cygdrive/c/NDK/sysroot/include/malloc.h
#

BEGIN {
    # TODO: We could determine this dynamically before calling this script
    CYGDRIVE_PREFIX = "/cygdrive/"
}

{
    # First case: D:/Stuff/source.o: \
    if ( $0 ~ /^[A-Za-z]:/ ) {
        print CYGDRIVE_PREFIX tolower(substr($0,1,1)) "/" substr($0,4)
    }
    # Second case: <space>D:/Stuff/source.h
    else if ( $0 ~ /^ [A-Za-z]:/ ) {
        print " " CYGDRIVE_PREFIX tolower(substr($0,2,1)) "/" substr($0,5)
    }
    else {
        print $0
    }
}
